@@ -1,4 +1,5 @@
 from django.utils.translation import get_language
+from django.db import DatabaseError
 
 from jingo import register
 
@@ -11,7 +12,7 @@ def _(text, context=None):
         trans = Translation.objects.translate(text, get_language(), context)
         translated = trans[0].text
         return translated or text
-    except (Translation.DoesNotExist, IndexError, TypeError):
+    except (Translation.DoesNotExist, IndexError, TypeError, DatabaseError):
         return text
 
 
